@@ -238,7 +238,8 @@ test_that("Completion of function arguments works", {
         c(
             "str(obj",
             "utils::str(obj",
-            "str(stats::o"
+            "str(stats::o",
+            "seq.int(fr"
         ),
         temp_file)
 
@@ -255,6 +256,10 @@ test_that("Completion of function arguments works", {
     result <- client %>% respond_completion(temp_file, c(2, 12))
     arg_items <- result$items %>% keep(~.$label == "object")
     expect_length(arg_items, 0)
+
+    result <- client %>% respond_completion(temp_file, c(3, 10))
+    arg_items <- result$items %>% keep(~ .$label == "from")
+    expect_length(arg_items, 1)
 })
 
 test_that("Completion of function arguments is case insensitive", {
@@ -321,7 +326,8 @@ test_that("Completion of function arguments preserves the order of arguments", {
         c(
             "eval(",
             "formatC(",
-            "print.default("
+            "print.default(",
+            "seq.int("
         ),
         temp_file)
 
@@ -344,6 +350,12 @@ test_that("Completion of function arguments preserves the order of arguments", {
         keep(~ identical(.$data$type, "parameter")) %>%
         map_chr(~ .$label)
     expect_identical(arg_items, names(formals(print.default)))
+
+    result <- client %>% respond_completion(temp_file, c(3, 8))
+    arg_items <- result$items %>%
+        keep(~ identical(.$data$type, "parameter")) %>%
+        map_chr(~ .$label)
+    expect_identical(arg_items, names(formals(args(seq.int))))
 })
 
 test_that("Completion of local function arguments works", {
@@ -867,3 +879,58 @@ test_that("Completion in Rmarkdown works", {
     result <- client %>% respond_completion(temp_file, c(11, 3))
     expect_length(result$items, 0)
 })
+
+test_that("Completion in Rmarkdown specified by languageId works", {
+    skip_on_cran()
+    client <- language_client()
+
+    temp_file <- withr::local_tempfile(fileext = ".md")
+    writeLines(
+        c(
+            "Title",
+            "",
+            "```{r}",
+            "str",
+            "file.c",
+            "fs::path",
+            "foo$sol",
+            ".Mac",
+            "grDev",
+            "TRU",
+            "```",
+            "str"
+        ),
+        temp_file
+    )
+
+    client %>% did_open(temp_file, languageId = "rmd")
+
+    result <- client %>% respond_completion(temp_file, c(3, 3))
+    expect_length(result$items %>% keep(~ .$label == "strsplit"), 1)
+    expect_length(result$items %>% keep(~ .$label == "strrep"), 1)
+
+    result <- client %>% respond_completion(temp_file, c(4, 6))
+    expect_length(result$items %>% keep(~ .$label == "file.choose"), 1)
+    expect_length(result$items %>% keep(~ .$label == "file.create"), 1)
+
+    result <- client %>% respond_completion(temp_file, c(5, 8))
+    expect_true("path_real" %in% (result$items %>% map_chr(~ .$label)))
+
+    result <- client %>% respond_completion(temp_file, c(6, 7))
+    expect_length(result$items %>% discard(~ .$kind == CompletionItemKind$Text), 0)
+
+    result <- client %>% respond_completion(temp_file, c(7, 4))
+    expect_length(result$items %>% keep(~ .$label == ".Machine"), 1)
+
+    result <- client %>% respond_completion(temp_file, c(8, 5))
+    expect_length(result$items %>% keep(~ .$label == "grDevices"), 1)
+
+    result <- client %>% respond_completion(temp_file, c(9, 3))
+    expect_length(result$items %>% keep(~ .$label == "TRUE"), 1)
+
+    result <- client %>% respond_completion(temp_file, c(10, 3))
+    expect_length(result$items, 0)
+
+    result <- client %>% respond_completion(temp_file, c(11, 3))
+    expect_length(result$items, 0)
+})
