@@ -36,7 +36,7 @@ test_that("Document Symbol works", {
     )
 })
 
-test_that("Recognize symbols created by delayedAssign()/assign()/makeActiveBinding()", {
+test_that("Recognize symbols created by delayedAssign/assign/makeActiveBinding", {
     skip_on_cran()
     client <- language_client()
 
@@ -59,7 +59,7 @@ test_that("Recognize symbols created by delayedAssign()/assign()/makeActiveBindi
         "makeActiveBinding('a5', function() 5, .GlobalEnv)",
         "makeActiveBinding('a6', function() 6, new.env())",
         "assign(value = '1', x = 'assign1')",
-        "assign('assign2', 2, pos = -1L)",
+        "assign('assign2', 2, pos = -1)",
         "assign('assign3', 3, pos = environment())",
         "assign('assign4', 4, pos = new.env())"
     ), defn_file)
@@ -73,6 +73,32 @@ test_that("Recognize symbols created by delayedAssign()/assign()/makeActiveBindi
     )
 })
 
+test_that("Document symbols are robust to invalid source", {
+    skip_on_cran()
+    client <- language_client()
+
+    defn_file <- withr::local_tempfile(fileext = ".R")
+    writeLines(c(
+        "'' <- 2",
+        "assign('', 3)",
+        "delayedAssign('', 1)",
+        "makeActiveBinding('', 2)",
+        "makeActiveBinding(x, 1)",
+        "assign('var1', 1, nonexist_arg = TRUE)",
+        "delayedAssign('var1', 1, nonexist_arg = TRUE)",
+        "makeActiveBinding('var1', 1, nonexist_arg = TRUE)",
+        "d1 <- 1"
+    ), defn_file)
+
+    client %>% did_save(defn_file)
+    result <- client %>% respond_document_symbol(defn_file)
+
+    expect_setequal(
+        result %>% map_chr(~ .$name),
+        c("d1")
+    )
+})
+
 test_that("Document section symbol works", {
     skip_on_cran()
     client <- language_client(capabilities = list(
